from Products.Archetypes.public import *
from Products.ATContentTypes.types.ATFile import ATFile
from Products.ATContentTypes.types.schemata import ATFileSchema
from Products.ATColorPickerWidget.ColorPickerWidget import ColorPickerWidget
from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.utils import getToolByName
from AccessControl import ClassSecurityInfo
from swfHeaderData import analyseContent
from config import *


schema = ATFileSchema + Schema((

    IntegerField('scale',
                 required = True,
                 searchable = False,
                 default = 100,
                 validators = ('isInt'),
                 vocabulary = SCALE_LIST,
                 widget=SelectionWidget(label = 'Scale',
                                        label_msgid ='label_scale',
                                        description = 'Scale of the flash movie.',
                                        description_msgid ="desc_scale",
                                        i18n_domain='ATFlashMovie'),
                 ),

    StringField('bgcolor',
                 required = True,
                 searchable = False,
                 default = '#FFFFFF',
                 widget=ColorPickerWidget(label = 'Background Color',
                                        label_msgid ='label_bgcolor',
                                        description = 'Select background color of the flash movie.',
                                        description_msgid ="desc_bgcolor",
                                        i18n_domain='ATFlashMovie'),
                 ),

    IntegerField('width',
                 required = False,
                 searchable = False,
                 validators = ('isInt'),
                 widget=IntegerWidget(label ='Width', modes= ('view',),
                                      label_msgid ='label_width',
                                      description = 'Width of flash movie.',
                                      description_msgid ="desc_width",
                                      i18n_domain='ATFlashMovie'),
                 ),
    
    IntegerField('height',
                 required = False,
                 searchable = False,
                 validators = ('isInt'),
                 widget=IntegerWidget(label ='Height', modes= ('view',),
                                      label_msgid ='label_height',
                                      description = 'Height of flash movie.',
                                      description_msgid ="desc_hight",
                                      i18n_domain='ATFlashMovie'),
                 ),

    StringField('flashversion',
                required = False,
                searchable = False,
                widget=StringWidget(modes= ('view',),
                                    label ='Flash Version',
                                    label_msgid ='label_flashversion',
                                    i18n_domain='ATFlashMovie'),
                ),
    ))


class ATFlashMovie(ATFile):
    """A flash file archetype type"""
    
    schema = schema
    archetype_name = 'Flash Movie'
    meta_type = 'FlashMovie'
    portal_type = 'FlashMovie'
    content_icon = 'flashmovie_icon.gif'
    
    global_allow = True
    
    actions = ({
        'id': 'view',
        'name': 'View',
        'action': 'string:${object_url}/flashmovie_view',
        'permissions': (CMFCorePermissions.View,)
        },)

    security = ClassSecurityInfo()

    security.declareProtected(CMFCorePermissions.ModifyPortalContent, 'setFile')
    def setFile(self, value, **kwargs):
        ATFile.setFile(self, value, **kwargs)

        if value:
            value.seek(0) # rewind
            tags = analyseContent(value.read(1024))
            self.setWidth(tags['width'])
            self.setHeight(tags['height'])
            self.setFlashversion(tags['flashversion'])

    def getHeight(self):
        if self.height:
            return (self.height * (self.getScale() / 100.0))
        else:
            return None
    
    def getWidth(self):
        if self.width:
            return (self.width * (self.getScale() / 100.0))
        else:
            return None

    security.declarePublic('getIcon')
    def getIcon(self, relative_to_portal=0):

        icon = self.content_icon

        if relative_to_portal:
            return icon
        else:
            utool = getToolByName( self, 'portal_url' )
            # Relative to REQUEST['BASEPATH1']
            res = utool(relative=1) + '/' + icon
            while res[:1] == '/':
                res = res[1:]
            return res

registerType(ATFlashMovie)


